@@ -1,11 +1,11 @@
 from django_rq import job
 from django.core.mail import send_mail
-from whistle.managers import NoticeManager
+from whistle.managers import NotificationManager
 from whistle import settings as whistle_settings
 
 
 def notify(request, recipient, event, actor=None, object=None, target=None, details=''):
-    NoticeManager.notify(request, recipient, event, actor, object, target, details)
+    NotificationManager.notify(request, recipient, event, actor, object, target, details)
 
 
 @job(whistle_settings.REDIS_QUEUE)
